@@ -5,6 +5,7 @@ from cement.utils.version import get_version_banner
 from ..core.version import get_version
 from cement import Controller, ex
 from ..utils.utils import CommandError
+from dotenv import dotenv_values
 
 VERSION_BANNER = """
 Build and Deploy with Kluff %s
@@ -91,16 +92,34 @@ class AppSetup(Controller):
         )
     def deploy(self):
         self.app.log.info(f'deploying plugin')
-        try:
-            plugin_name = os.path.split(os.getcwd())[1]
-            backend_path = os.path.join(os.getcwd(), 'backend')
-            print(backend_path)
-            backend_image_tag = f'{plugin_name}-backend:latest'
-            print(backend_image_tag)
-            print(self.container_registry)
-            os.system(f'cd {self.backend_path}')
-            os.system(f'docker build -t {backend_image_tag} .')
-            os.system(f'docker tag {backend_image_tag} {self.container_registry}/{backend_image_tag}')
-            os.system(f'docker push {self.container_registry}/{backend_image_tag}')
-        except OSError as e:
-            raise CommandError(e)
+
+        # ####################################
+        # These steps will be moved to CI/CD #
+        ######################################
+
+        plugin_name = os.path.split(os.getcwd())[1]
+        backend_path = os.path.join(os.getcwd(), 'backend')
+        backend_image_tag = f'{plugin_name}-backend:latest'
+        registry_image_name = f'{self.container_registry}/{backend_image_tag}'
+        env_vars = dotenv_values(".env")
+        env_str = ''
+        for key, value in env_vars.items():
+            env_str += f'--env {key}:{value} '
+
+        os.system(f'cd {backend_path} && docker build -t {backend_image_tag} .')
+        os.system(f'docker tag {backend_image_tag} {self.container_registry}/{backend_image_tag}')
+        os.system(f'docker push {registry_image_name}')
+        os.system(f'cd {backend_path} && faas-cli deploy --image {registry_image_name} --name {plugin_name} {env_str}')
+        print(f'cd {backend_path} && faas-cli deploy --image {registry_image_name} --name {plugin_name} {env_str}')
+        #############################
+        # For end users
+        #############################
+
+        # Initialize this repo as GIT repo
+        # Integrate our custom GitLab instance
+        # Create a repo on Gitlab instance for plugin
+        # Push backend/frontend to Same repo
+
+        # CI/CD will deploy backend to openFaaS in kubernetes cluster
+        # and frontend to some CDN/Cloudfront/S3 etc
+
